@@ -12,6 +12,9 @@ import copy
 
 sys.path.append("..")
 
+import matplotlib
+matplotlib.use("WXAgg")
+
 import wx
 
 if wx.__version__ < "4.":
@@ -27,42 +30,44 @@ else:
 
     wx.Window.SetToolTipString = sttip
 
-from dict_LaueTools import LAUETOOLSFOLDER
+if sys.version_info.major == 3:
+    import LaueTools.dict_LaueTools as dictLT
+else:
+    import dict_LaueTools as dictLT
+
+LAUETOOLSFOLDER = dictLT.LAUETOOLSFOLDER
 LaueToolsProjectFolder = os.path.abspath(LAUETOOLSFOLDER)
 print("LaueToolProjectFolder", LaueToolsProjectFolder)
 
-import FileSeries.multigrainFS as MGFS
-import FileSeries.module_graphique as modgraph
-import param_multigrain as PAR
+from . import multigrainFS as MGFS
+
+# #import FileSeries.multigrainFS as MGFS
 
 try:
     import tables
 
     PYTABLES_EXISTS = True
 except IOError:
-    print("Unable to load tables module from pytables...")
+    print("Unable to load tables module from pytables... Try install vitables by \n pip install vitables")
     PYTABLES_EXISTS = False
 
-LIST_TXTPARAM_BS = [
-    "Folder .fit file",
-    "Folder Result file",
-    "prefix .fit file",
-    ".fit suffix",
-    "Nbdigits filename",
-    "startindex",
-    "finalindex",
-    "stepindex",
-    "stiffness file (.stf)",
-    "Material",
-    "file xyz",
-    "nx",
-    "ny",
-    "fast axis",
-    "stepxy",
-]
+LIST_TXTPARAM_BS = ["Folder .fit file",
+                    "Folder Result file",
+                    "prefix .fit file",
+                    ".fit suffix",
+                    "Nbdigits filename",
+                    "startindex",
+                    "finalindex",
+                    "stepindex",
+                    "stiffness file (.stf)",
+                    "Material",
+                    "file xyz",
+                    "nx",
+                    "ny",
+                    "fast axis",
+                    "stepxy"]
 
-TIP_BS = [
-    "Folder containing indexed Peaks List .fit files",
+TIP_BS = ["Folder containing indexed Peaks List .fit files",
     "Folder to write summary files",
     "Prefix for .fit files filename prefix####.fit",
     'file suffix. Default ".fit"',
@@ -92,9 +97,7 @@ DICT_TOOLTIP[
 
 class MainFrame_BuildSummary(wx.Frame):
     def __init__(self, parent, _id, title, _initialparameters):
-        wx.Frame.__init__(
-            self, parent, _id, title, wx.DefaultPosition, wx.Size(1000, 700)
-        )
+        wx.Frame.__init__(self, parent, _id, title, wx.DefaultPosition, wx.Size(1000, 700))
 
         self.initialparameters = _initialparameters
         print('self.initialparameters', self.initialparameters)
@@ -143,13 +146,11 @@ class MainFrame_BuildSummary(wx.Frame):
                 elif kk == 1:
                     btnbrowse.Bind(wx.EVT_BUTTON, self.OnbtnBrowse_results_folder)
                     btnbrowse.SetToolTipString(
-                        "Select output folder for summary results files"
-                    )
+                        "Select output folder for summary results files")
                 elif kk == 2:
                     btnbrowse.Bind(wx.EVT_BUTTON, self.OnbtnBrowse_filepathout_fit)
                     btnbrowse.SetToolTipString(
-                        "Select one .fit file to get (and guess) the generic prefix of all .fit filenames"
-                    )
+                        "Select one .fit file to get (and guess) the generic prefix of all .fit filenames")
                 elif kk == 8:
                     btnbrowse.Bind(wx.EVT_BUTTON, self.OnbtnBrowse_stiffnessfile)
                     btnbrowse.SetToolTipString("Select stiffness .stf file")
@@ -169,9 +170,7 @@ class MainFrame_BuildSummary(wx.Frame):
         #         none10 = wx.StaticText(self.panel, -1, "")
         #         grid.Add(none10)
 
-        txt_fileparameters = wx.StaticText(
-            self.panel, -1, "Step 1 : Build (index,x,y) file"
-        )
+        txt_fileparameters = wx.StaticText(self.panel, -1, "Step 1 : Build (index,x,y) file")
         grid.Add(txt_fileparameters)
         font = wx.Font(12, wx.MODERN, wx.ITALIC, wx.NORMAL)
         txt_fileparameters.SetFont(font)
@@ -181,24 +180,19 @@ class MainFrame_BuildSummary(wx.Frame):
         grid.Add(txt_none_2)
 
         btn_fabrication_to_hand = wx.Button(
-            self.panel, -1, "Build manually", size=(200, -1)
-        )
+            self.panel, -1, "Build manually", size=(200, -1))
         grid.Add(btn_fabrication_to_hand)
         btn_fabrication_to_hand.Bind(wx.EVT_BUTTON, self.OnbuildManually)
         btn_fabrication_with_image = wx.Button(
-            self.panel, -1, "Build from Images Info", size=(200, -1)
-        )
+            self.panel, -1, "Build from Images Info", size=(200, -1))
         btn_fabrication_with_image.Disable()
         grid.Add(btn_fabrication_with_image)
         btn_fabrication_with_image.Bind(
-            wx.EVT_BUTTON, self.Onbtn_fabrication_with_image
-        )
+            wx.EVT_BUTTON, self.Onbtn_fabrication_with_image)
         txt_none_3 = wx.StaticText(self.panel, -1, "")
         grid.Add(txt_none_3)
 
-        txt_buildsummary = wx.StaticText(
-            self.panel, -1, "Step 2 : Build summary files "
-        )
+        txt_buildsummary = wx.StaticText(self.panel, -1, "Step 2 : Build summary files ")
         grid.Add(txt_buildsummary)
 
         txt_buildsummary.SetFont(font)
@@ -229,17 +223,13 @@ class MainFrame_BuildSummary(wx.Frame):
         self.Layout()
 
         # tooltips ----------
-        btn_fabrication_to_hand.SetToolTipString(
-            "Create a 3 columns file: image_index, x, y"
-        )
-        btnStart.SetToolTipString(
-            "Start reading all .fit files and build summary files in folder results"
-        )
+        btn_fabrication_to_hand.SetToolTipString("Create a 3 columns file: image_index, x, y")
+        btnStart.SetToolTipString("Start reading all .fit files and build summary files in folder results")
 
         self.builddatfile.SetToolTipString("Build an ASCII summary file with extension .dat")
         self.buildhdf5.SetToolTipString("Build a hdf5 file system file")
 
-    def OnbtnBrowse_fitfilesfolder(self, evt):
+    def OnbtnBrowse_fitfilesfolder(self, _):
         folder = wx.DirDialog(self, "Select folder for refined peaklist .fit files")
         if folder.ShowModal() == wx.ID_OK:
 
@@ -250,7 +240,7 @@ class MainFrame_BuildSummary(wx.Frame):
             mainpath = os.path.split(abspath)[0]
             self.list_txtctrl[1].SetValue(mainpath)
 
-    def OnbtnBrowse_results_folder(self, evt):
+    def OnbtnBrowse_results_folder(self, _):
         folder = wx.DirDialog(self, "Select folder for writing summary results")
         if folder.ShowModal() == wx.ID_OK:
 
@@ -258,21 +248,15 @@ class MainFrame_BuildSummary(wx.Frame):
 
             self.list_txtctrl[1].SetValue(abspath)
 
-    def OnbtnBrowse_filepathout_fit(self, evt):
-        folder = wx.FileDialog(
-            self,
+    def OnbtnBrowse_filepathout_fit(self, _):
+        folder = wx.FileDialog(self,
             "Select refined Peaklist File .fit for catching prefix",
-            wildcard="Refined PeakList (*.fit)|*.fit|All files(*)|*",
-        )
+            wildcard="Refined PeakList (*.fit)|*.fit|All files(*)|*",)
 
         if folder.ShowModal() == wx.ID_OK:
 
             abspath = folder.GetPath()
-
-            #             print "folder.GetPath()", abspath
-
             filename = os.path.split(abspath)[-1]
-            #             print "filename", filename
             intension, extension = filename.split(".")
 
             self.list_txtctrl[3].SetValue("." + extension)
@@ -280,38 +264,28 @@ class MainFrame_BuildSummary(wx.Frame):
             nbdigits = int(self.list_txtctrl[4].GetValue())
             self.list_txtctrl[2].SetValue(intension[:-nbdigits])
 
-    def OnbtnBrowse_stiffnessfile(self, evt):
-        folder = wx.FileDialog(
-            self,
-            "Select stiffness file .stf",
-            wildcard="stiffness file (*.stf)|*.stf|All files(*)|*",
-        )
+    def OnbtnBrowse_stiffnessfile(self, _):
+        folder = wx.FileDialog(self, "Select stiffness file .stf",
+            wildcard="stiffness file (*.stf)|*.stf|All files(*)|*")
         if folder.ShowModal() == wx.ID_OK:
 
             self.list_txtctrl[8].SetValue(folder.GetPath())
 
-    def OnbtnChangeparameters(self, event, objet_BS, objet_BSi):
+    def OnbtnChangeparameters(self, _):
 
         wx.MessageBox("Sorry! This will be implemented very soon!", "INFO")
         return
-        # PSboard = SetParametersFrame(self, -1, 'New parameters',
-        #                                       objet_BS, objet_BSi, self.list_txtctrl)
-        # PSboard.Show(True)
 
-    def OnbuildManually(self, event):
+    def OnbuildManually(self, _):
         PSboard = Manual_XYZfilecreation_Frame(
-            self, -1, "File sample XYZ position: Manual creation Board"
-        )
+            self, -1, "File sample XYZ position: Manual creation Board")
         PSboard.Show(True)
 
-    def Onbtn_fabrication_with_image(self, event):
+    def Onbtn_fabrication_with_image(self, _):
         wx.MessageBox("Sorry! This will be implemented very soon!", "INFO")
         return
-        # PSboard = SetParameters_BuildSummary_fabricationImage(self, -1,
-        #                 'Entryparameters_fabricationimage')
-        # PSboard.Show(True)
 
-    def OnCreateSummary(self, event):
+    def OnCreateSummary(self, _):
 
         if not self.builddatfile.GetValue() and not self.buildhdf5.GetValue():
             wx.MessageBox("Check at least one type of summary file!", "Error")
@@ -334,52 +308,42 @@ class MainFrame_BuildSummary(wx.Frame):
 
         filexyz = str(self.list_txtctrl[10].GetValue())
 
-        #         if not os.path.exists(str(objet_BS.list_valueparamBS[0]) + 'summary_new'):
-        #                 os.makedirs(str(objet_BS.list_valueparamBS[0]) + 'summary_new')
-        #         modgraph.outfilename = (str(objet_BS.list_valueparamBS[0]) + 'summary_new')
-
         if self.builddatfile.GetValue():
 
-            allres, fullpath_summary_filename = MGFS.build_summary(
-                image_indices,
-                folderfitfiles,
-                prefix,
-                suffix,
-                filexyz,
-                startindex=startindex,
-                finalindex=finalindex,
-                number_of_digits_in_image_name=nbdigits_for_zero_padding,
-                folderoutput=folderresult,
-                default_file=DEFAULT_FILE,
-            )
+            _, fullpath_summary_filename = MGFS.build_summary(
+                                    image_indices,
+                                    folderfitfiles,
+                                    prefix,
+                                    suffix,
+                                    filexyz,
+                                    startindex=startindex,
+                                    finalindex=finalindex,
+                                    number_of_digits_in_image_name=nbdigits_for_zero_padding,
+                                    folderoutput=folderresult,
+                                    default_file=DEFAULT_FILE)
 
             print("fullpath_summary_filename", fullpath_summary_filename)
 
             fullpath_summary_filename = MGFS.add_columns_to_summary_file_new(
-                fullpath_summary_filename,
-                elem_label=key_material,
-                filestf=stiffnessfile,
-            )
+                                                    fullpath_summary_filename,
+                                                    elem_label=key_material,
+                                                    filestf=stiffnessfile)
 
-            wx.MessageBox(
-                "Operation Successful! \t \t Summary file created here: %s"
-                % fullpath_summary_filename
-            )
+            wx.MessageBox("Operation Successful! \t \t Summary file created here: %s"
+                % fullpath_summary_filename)
         if self.buildhdf5.GetValue():
             from Lauehdf5 import Add_allspotsSummary_from_fitfiles
 
             "\n\n ****** \nBuilding a hdf5 summary file\n*********  \n\n"
             Summary_HDF5_filename = prefix + ".h5"
-            Add_allspotsSummary_from_fitfiles(
-                Summary_HDF5_filename,
-                prefix,
-                folderfitfiles,
-                image_indices,
-                Summary_HDF5_dirname=folderfitfiles,
-                number_of_digits_in_image_name=4,
-                filesuffix=".fit",
-                nb_of_spots_per_image=300,
-            )
+            Add_allspotsSummary_from_fitfiles(Summary_HDF5_filename,
+                                                prefix,
+                                                folderfitfiles,
+                                                image_indices,
+                                                Summary_HDF5_dirname=folderfitfiles,
+                                                number_of_digits_in_image_name=nbdigits_for_zero_padding,
+                                                filesuffix=".fit",
+                                                nb_of_spots_per_image=300)
 
 
 class Manual_XYZfilecreation_Frame(wx.Frame):
@@ -387,9 +351,8 @@ class Manual_XYZfilecreation_Frame(wx.Frame):
     GUI class for setting parameters to build xyz file 
     """
     def __init__(self, parent, _id, title):
-        wx.Frame.__init__(
-            self, parent, _id, title, wx.DefaultPosition, wx.Size(350, 300)
-        )
+        wx.Frame.__init__(self, parent, _id, title, wx.DefaultPosition,
+                                                        wx.Size(350, 300))
         self.parent = parent
         self.panel = wx.Panel(self)
 
@@ -405,8 +368,7 @@ class Manual_XYZfilecreation_Frame(wx.Frame):
         proposedfilexyname = '{}_{}_to_{}_xy.dat'.format(
                             self.parent.list_txtctrl[2].GetValue(),
                             self.parent.list_txtctrl[5].GetValue(),
-                            self.parent.list_txtctrl[6].GetValue()
-                            )
+                            self.parent.list_txtctrl[6].GetValue())
         self.parent.initialparameters[10] = os.path.join(self.parent.list_txtctrl[1].GetValue(),
                                                 proposedfilexyname)
 
@@ -423,74 +385,61 @@ class Manual_XYZfilecreation_Frame(wx.Frame):
 
                 grid.Add(wx.Button(self.panel, kk + 9, "?", size=(25, 25)))
 
-        self.Bind(
-            wx.EVT_BUTTON, lambda event: self.OnbtnBrowse_filepathout(self), id=12
-        )
+        self.Bind(wx.EVT_BUTTON, lambda event: self.OnbtnBrowse_filepathout(self), id=12)
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_filepathout(self), id=13)
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_fileprefix(self), id=14)
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_filesuffix(self), id=15)
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_nbdigits(self), id=16)
-        #         self.Bind(wx.EVT_BUTTON, lambda event: self.OnbtnChange_indimg(self), id=25)
 
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_indimg(self), id=17)
-        #       id = 16 correspond à la lignée qui saute, donc pas d'association avec bouton
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onfilexyz_help(self), id=19)
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_nx(self), id=20)
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_ny(self), id=21)
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_xfast(self), id=22)
-        #         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_yfast(self), id=23)
         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_xstep(self), id=23)
-        #         self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_ystep(self), id=25)
 
         btnStart_BS_fabricationHand = wx.Button(
-            self.panel, -1, "Create File with array Index,X,Y", size=(-1, 60)
-        )
+            self.panel, -1, "Create File with array Index,X,Y", size=(-1, 60))
 
         btnStart_BS_fabricationHand.Bind(wx.EVT_BUTTON, self.start_manualXYZ)
-        #layout---
+        #layout---------------------------
         vbox = wx.BoxSizer(wx.VERTICAL)
         vbox.Add(grid, 0, wx.EXPAND)
         vbox.Add(btnStart_BS_fabricationHand, 0, wx.EXPAND)
 
         self.help = wx.TextCtrl(
-            self.panel, -1, "", style=wx.TE_MULTILINE | wx.TE_READONLY, size=(250, 100)
-        )
+            self.panel, -1, "", style=wx.TE_MULTILINE | wx.TE_READONLY, size=(250, 100))
         vbox.Add(self.help, 1, wx.EXPAND)
 
         self.panel.SetSizer(vbox, wx.EXPAND)
 
-    def Onbtnhelp_nbdigits(self, event):
+    def Onbtnhelp_nbdigits(self, _):
         helpstring = "a remplir"
         self.help.SetValue(str(helpstring))
 
-    def Onbtnhelp_filepathout(self, event):
+    def Onbtnhelp_filepathout(self, _):
         helpstring = "a remplir"
         self.help.SetValue(str(helpstring))
 
-    def Onfilexyz_help(self, event):
+    def Onfilexyz_help(self, _):
         helpstring = "file xyz : full path to file xy with 3 columns (imagefile_index x y)"
         self.help.SetValue(str(helpstring))
 
-    def Onbtnhelp_nx(self, event):
+    def Onbtnhelp_nx(self, _):
         helpstring = 'Number of images (points) per line along the "fast axis" (X (resp Y) axis is "fast axis" is set to "x" resp. "y"))'
         self.help.SetValue(str(helpstring))
 
-    def Onbtnhelp_ny(self, event):
+    def Onbtnhelp_ny(self, _):
         helpstring = 'Number of images (points) per column along the "slow axis"'
         self.help.SetValue(str(helpstring))
 
-    def Onbtnhelp_xfast(self, event):
+    def Onbtnhelp_xfast(self, _):
         helpstring = 'sample direction for fast motor axis: "x"or "y"'
         self.help.SetValue(str(helpstring))
 
-    #     def Onbtnhelp_yfast(self, event):
-    #         helpstring = 'sample direction for slow motor axis'
-    #         self.help.SetValue(str(helpstring))
-    def Onbtnhelp_xstep(self, event):
+    def Onbtnhelp_xstep(self, _):
         helpstring = "steps (Dx,Dy) along resp. fast and slow axes in micrometer. Dx and Dy can be negative.\n"
-        helpstring += (
-            "By increasing image index position along fast axis increases by Dx.\n"
-        )
+        helpstring += "By increasing image index position along fast axis increases by Dx.\n"
         helpstring += "Between each line position along slow axis increases by Dy"
         self.help.SetValue(str(helpstring))
 
@@ -500,16 +449,12 @@ class Manual_XYZfilecreation_Frame(wx.Frame):
     #     def Onbtnhelp_indimg(self, event):
     #         helpstring = 'a remplir'
     #         self.help.SetValue(str(helpstring))
-    def OnbtnBrowse_filepathout(self, event):
+    def OnbtnBrowse_filepathout(self, _):
         folder = wx.DirDialog(self, "os.path.dirname(guest)")
         if folder.ShowModal() == wx.ID_OK:
             self.list_txtctrl_manual[2].SetValue(folder.GetPath())
 
-    def OnbtnChange_indimg(self, event):
-        PSboard = New_indimg(None, -1, "New indimg", self.list_txtctrl_manual)
-        PSboard.Show(True)
-
-    def start_manualXYZ(self, event):
+    def start_manualXYZ(self, _):
         """
         read parameters and launch creation of file xy
         """
@@ -537,271 +482,26 @@ class Manual_XYZfilecreation_Frame(wx.Frame):
 
         print(self.parent.list_txtctrl)
 
-        prefix = str(self.parent.list_txtctrl[2].GetValue())
+        # prefix = str(self.parent.list_txtctrl[2].GetValue())
 
         outfilename = str(self.list_txtctrl_manual[0].GetValue())
 
         if check == 1:
             # writing filexyz with xy for map sample description in
-            MGFS.build_xy_list_by_hand( outfilename, nx, ny, xfast, yfast, xstep, ystep,
+            MGFS.build_xy_list_by_hand(outfilename, nx, ny, xfast, yfast, xstep, ystep,
                         startindex=int(self.parent.list_txtctrl[5].GetValue()),
                         lastindex=int(self.parent.list_txtctrl[6].GetValue()), )
 
             self.parent.list_txtctrl[10].SetValue(outfilename)
 
             wx.MessageBox(
-                "Operation Successful! \t \t Filexyz created: %s" % outfilename
-            )
+                "Operation Successful! \t \t Filexyz created: %s" % outfilename)
         else:
             wx.MessageBox("Files's path or input datas are missing!")
 
         self.Destroy()
 
 
-class New_indimg(wx.Frame):
-    def __init__(self, parent, _id, title, list_txtctrl_hand):
-        wx.Frame.__init__(
-            self, parent, _id, title, wx.DefaultPosition, wx.Size(700, 700)
-        )
-
-        self.panel = wx.Panel(self)
-        if WXPYTHON4:
-            grid = wx.FlexGridSizer(3, 10, 10)
-        else:
-            grid = wx.FlexGridSizer(5, 3)
-        grid.SetFlexibleDirection(wx.HORIZONTAL)
-
-        self.list_txtctrl_new = []
-        self.list_indimg = ["Nbpicture1", "Nblastpicture", "increment"]
-
-        for kk, elem in enumerate(self.list_indimg):
-            grid.Add(wx.StaticText(self.panel, -1, elem))
-            self.txtctrl = wx.TextCtrl(self.panel, -1, "", size=(500, 25))
-            self.list_txtctrl_new.append(self.txtctrl)
-            grid.Add(self.txtctrl)
-            grid.Add(wx.Button(self.panel, kk + 10, "?", size=(25, 25)))
-
-        self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_nbpicture1(self), id=10)
-        self.Bind(
-            wx.EVT_BUTTON, lambda event: self.Onbtnhelp_nblastpicture(self), id=11
-        )
-        self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_increment(self), id=12)
-
-        btnOK = wx.Button(self.panel, -1, "OK")
-        grid.Add(btnOK)
-        btnOK.Bind(wx.EVT_BUTTON, lambda event: self.OnbtnOK(self, list_txtctrl_hand))
-
-        vbox = wx.BoxSizer(wx.VERTICAL)
-        vbox.Add(grid, 0, wx.EXPAND)
-        self.help = wx.TextCtrl(
-            self.panel, -1, "", style=wx.TE_MULTILINE | wx.TE_READONLY, size=(100, 300)
-        )
-        vbox.Add(self.help, 0, wx.EXPAND)
-
-        self.panel.SetSizer(vbox, wx.EXPAND)
-
-    def Onbtnhelp_nbpicture1(self, event):
-        txt = "a remplir"
-        self.help.SetValue(str(txt))
-
-    def Onbtnhelp_nblastpicture(self, event):
-        txt = "a remplir"
-        self.help.SetValue(str(txt))
-
-    def Onbtnhelp_increment(self, event):
-        txt = "a remplir"
-        self.help.SetValue(str(txt))
-
-    def OnbtnOK(self, event, list_txtctrl_hand):
-        modgraph.nbpicture1 = int(self.list_txtctrl_new[0].GetValue())
-        modgraph.nblastpicture = int(self.list_txtctrl_new[1].GetValue())
-        modgraph.increment = int(self.list_txtctrl_new[2].GetValue())
-        list_txtctrl_hand[6].SetValue(
-            str(
-                "range("
-                + str(self.list_txtctrl_new[0].GetValue())
-                + ","
-                + str(self.list_txtctrl_new[1].GetValue())
-                + ","
-                + str(self.list_txtctrl_new[2].GetValue())
-                + ")"
-            )
-        )
-        self.Destroy()
-
-
-class SetParameters_BuildSummary_fabricationImage(wx.Frame):
-    """
-    Non used GUI class to extract in a clever way map parameters ...
-    """
-    def __init__(self, parent, _id, title, objet_BSi, manag, list_txtctrl):
-        wx.Frame.__init__(
-            self, parent, _id, title, wx.DefaultPosition, wx.Size(1000, 900)
-        )
-
-        self.panel = wx.Panel(self)
-        if WXPYTHON4:
-            grid = wx.FlexGridSizer(4, 10, 10)
-        else:
-            grid = wx.FlexGridSizer(6, 4)
-
-        grid.SetFlexibleDirection(wx.HORIZONTAL)
-
-        self.list_txtctrl_image = []
-
-        for kk, elem in enumerate(objet_BSi.list_txtparamBSi):
-            if kk > 1 and kk < 8:
-                if kk != 6:
-                    grid.Add(wx.StaticText(self.panel, -1, elem))
-                    self.txtctrl = wx.TextCtrl(self.panel, -1, "", size=(500, 25))
-                    self.txtctrl.SetValue(str(objet_BSi.list_valueparamBSi[kk]))
-                    self.list_txtctrl_image.append(self.txtctrl)
-                    grid.Add(self.txtctrl)
-                    if kk == 2 or kk == 7:
-                        grid.Add(wx.Button(self.panel, kk + 10, "Browse"))
-                    else:
-                        nothing = wx.StaticText(self.panel, -1, "")
-                        grid.Add(nothing)
-                    grid.Add(wx.Button(self.panel, kk + 18, "?", size=(25, 25)))
-                else:
-                    grid.Add(wx.StaticText(self.panel, -1, elem))
-                    self.txtctrl = wx.TextCtrl(self.panel, -1, "", size=(500, 25))
-                    self.txtctrl.SetValue(str(objet_BSi.list_valueparamBSi[kk]))
-                    self.list_txtctrl_image.append(self.txtctrl)
-                    grid.Add(self.txtctrl)
-                    grid.Add(wx.Button(self.panel, 26, "Change Indimg"))
-                    nothing = wx.StaticText(self.panel, -1, "")
-                    grid.Add(nothing)
-            else:
-                self.list_txtctrl_image.append("")
-
-        print("list_txt_image", self.list_txtctrl_image)
-        self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_filepathout(self), id=20)
-        self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_fileprefix(self), id=21)
-        self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_filesuffix(self), id=22)
-        self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_nbdigits(self), id=23)
-        self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnhelp_filepathim(self), id=25)
-        self.Bind(wx.EVT_BUTTON, lambda event: self.Onbtnchangeindimg(self), id=26)
-        self.Bind(
-            wx.EVT_BUTTON, lambda event: self.OnbtnBrowse_filepathout(self), id=12
-        )
-        self.Bind(wx.EVT_BUTTON, lambda event: self.OnbtnBrowse_filepathim(self), id=17)
-
-        btnStart_BS_fabricationImage = wx.Button(self.panel, -1, "START")
-        grid.Add(btnStart_BS_fabricationImage)
-        btnStart_BS_fabricationImage.Bind(
-            wx.EVT_BUTTON,
-            lambda event: self.OnbtnStart_BS_fabricationImage(
-                self, manag, objet_BSi, list_txtctrl
-            ),
-        )
-
-        vbox = wx.BoxSizer(wx.VERTICAL)
-        vbox.Add(grid, 0, wx.EXPAND)
-        self.help = wx.TextCtrl(
-            self.panel, -1, "", style=wx.TE_MULTILINE | wx.TE_READONLY, size=(100, 300)
-        )
-        vbox.Add(self.help, 0, wx.EXPAND)
-
-        self.panel.SetSizer(vbox, wx.EXPAND)
-
-    def Onbtnhelp_fileprefix(self, event):
-        txt = "a remplir"
-        self.help.SetValue(str(txt))
-
-    def Onbtnhelp_filesuffix(self, event):
-        txt = "a remplir"
-        self.help.SetValue(str(txt))
-
-    def Onbtnhelp_filepathim(self, event):
-        txt = "a remplir"
-        self.help.SetValue(str(txt))
-
-    def Onbtnhelp_filepathout(self, event):
-        txt = "a remplir"
-        self.help.SetValue(str(txt))
-
-    def Onbtnhelp_nbdigits(self, event):
-        txt = "a remplir"
-        self.help.SetValue(str(txt))
-
-    def Onbtnchangeindimg(self, event):
-        PSboard = New_indimg(None, -1, "Enter indimg", self.list_txtctrl_image)
-        PSboard.Show(True)
-
-    def OnbtnBrowse_filepathim(self, event):
-        folder = wx.DirDialog(self, "os.path.dirname(guest)")
-        if folder.ShowModal() == wx.ID_OK:
-            self.list_txtctrl_image[7].SetValue(folder.GetPath())
-
-    def OnbtnBrowse_filepathout(self, event):
-        folder = wx.DirDialog(self, "os.path.dirname(guest)")
-        if folder.ShowModal() == wx.ID_OK:
-            self.list_txtctrl_image[2].SetValue(folder.GetPath())
-
-    def OnbtnStart_BS_fabricationImage(self, event, manag, objet_BSi, list_txtctrl):
-        manag.Activate_BuildSummary()
-        manag.matrice_callfunctions[2, 2] = 2
-
-        check = 1
-        for k in range(2, 8):
-            if k == 5:
-                objet_BSi.list_valueparamBSi[k] = int(
-                    self.list_txtctrl_image[k].GetValue()
-                )
-                PAR.number_of_digits_in_image_name = int(
-                    self.list_txtctrl_image[k].GetValue()
-                )
-                list_txtctrl[k].SetValue(str(self.list_txtctrl_image[k].GetValue()))
-            elif k != 6:
-                objet_BSi.list_valueparamBSi[k] = str(
-                    self.list_txtctrl_image[k].GetValue()
-                )
-            else:
-                objet_BSi.list_valueparamBSi[k] = modgraph.indimg
-                list_txtctrl[k].SetValue(
-                    (
-                        "range"
-                        + "("
-                        + str(modgraph.nbpicture1)
-                        + ","
-                        + str(modgraph.nblastpicture)
-                        + ","
-                        + str(modgraph.increment)
-                        + ")"
-                    )
-                )
-            if (
-                objet_BSi.list_valueparamBSi[k] is None
-                or objet_BSi.list_valueparamBSi[k] == "None"
-                or objet_BSi.list_valueparamBSi[k] == ""
-            ):
-                check = 0
-
-        objet_BSi.list_valueparamBSi[9] = objet_BSi.list_valueparamBSi[3]
-        objet_BSi.list_valueparamBSi[10] = objet_BSi.list_valueparamBSi[4]
-
-        if not os.path.exists(str(objet_BSi.list_valueparamBSi[2]) + "xyz_"):
-            os.makedirs(str(objet_BSi.list_valueparamBSi[2] + "xyz_"))
-        modgraph.outfilenamexy = str(objet_BSi.list_valueparamBSi[2]) + "xyz_"
-        if check == 1:
-            objet_BSi.list_valueparamBSi[8] = MGFS.get_xyzech(
-                objet_BSi.list_valueparamBSi[7],
-                objet_BSi.list_valueparamBSi[3],
-                modgraph.indimg,
-                objet_BSi.list_valueparamBSi[4],
-                modgraph.outfilenamexy,
-            )
-            list_txtctrl[1].SetValue(str(objet_BSi.list_valueparamBSi[8]))
-            wx.MessageBox(
-                "Operation Successful! Files created here: %s"
-                % (modgraph.outfilenamexy)
-            )
-        else:
-            wx.MessageBox("Files's path or input datas are missing!")
-        self.Destroy()
-
-
 class Stock_parameters_BuildSummary_image:
     def __init__(self, list_txtparamBSi, list_valueparamBSi):
         self.list_txtparamBSi = list_txtparamBSi
@@ -833,8 +533,7 @@ def fill_list_valueparamBS(initialparameters_dict):
         initialparameters_dict["Map shape"][1],
         initialparameters_dict["Map shape"][0],
         initialparameters_dict["fast axis: x or y"],
-        initialparameters_dict["(stepX, stepY) microns"],
-    ]
+        initialparameters_dict["(stepX, stepY) microns"]]
     return list_valueparam_BS
 
 
@@ -848,10 +547,8 @@ print("MainFolder", MainFolder)
 
 initialparameters["IndexRefine PeakList Folder"] = os.path.join(MainFolder, "fitfiles")
 
-initialparameters["file xyz"] = os.path.join(
-    MainFolder, "fitfiles", "CuSi_xy_0_to_14.dat"
-)
-initialparameters["IndexRefine PeakList Prefix"] = "cusi_"
+initialparameters["file xyz"] = os.path.join(MainFolder, "fitfiles", "SiCustrain_0_to_5_xy.dat")
+initialparameters["IndexRefine PeakList Prefix"] = "SiCustrain"
 initialparameters["IndexRefine PeakList Suffix"] = ".fit"
 
 initialparameters["Map shape"] = (5, 3)  # (nb lines, nb images per line)
@@ -860,7 +557,7 @@ initialparameters["(stepX, stepY) microns"] = (1.0, 1.0)
 initialparameters["Material"] = "Si"
 initialparameters["stiffness file"] = os.path.join(MainFolder, "si.stf")
 
-initialparameters["nbdigits"] = 4
+initialparameters["nbdigits"] = 0
 initialparameters["startingindex"] = 0
 initialparameters["finalindex"] = 5
 initialparameters["stepindex"] = 1
@@ -868,17 +565,16 @@ initialparameters["fast axis: x or y"] = "x"
 
 list_valueparamBS = fill_list_valueparamBS(initialparameters)
 
-DEFAULT_FILE = os.path.join(
-    initialparameters["IndexRefine PeakList Folder"], "nanox2_400_0000.fit"
-)
+DEFAULT_FILE = os.path.join(initialparameters["IndexRefine PeakList Folder"],
+                                            "nanox2_400_0000.fit")
+
+def start():
+    BuildSummaryApp = wx.App()
+    BSFrame = MainFrame_BuildSummary(None, -1,
+                                "Build Summary Parameters Board", list_valueparamBS)
+    BSFrame.Show(True)
+    BuildSummaryApp.MainLoop()
 
 if __name__ == "__main__":
 
-
-
-    BuildSummaryApp = wx.App()
-    BSFrame = MainFrame_BuildSummary(
-        None, -1, "Build Summary Parameters Board", list_valueparamBS
-    )
-    BSFrame.Show(True)
-    BuildSummaryApp.MainLoop()
+    start()
