@@ -40,9 +40,9 @@ except (ImportError, SyntaxError):
     print("Missing modules or functions of multigrain.py. But It does not matter!")
 
 if sys.version_info.major == 3:
-    from .. import IOLaueTools as IOLT
-    from .. import indexingSpotsSet as ISS
-    from .. import dict_LaueTools as dictLT
+    import LaueTools.IOLaueTools as IOLT
+    import LaueTools.indexingSpotsSet as ISS
+    import LaueTools.dict_LaueTools as dictLT
 else:
     import IOLaueTools as IOLT
     import indexingSpotsSet as ISS
@@ -83,7 +83,7 @@ LIST_TXTPARAM_FILE_INDEXREFINE = ["Peak List .dat Folder",
 TIP_IR = ["Folder containing indexed Peaks List .dat files",
     "Folder containing (results) Peaks List .cor files",
     "Folder containing (results) indexed Peaks List .fit files",
-    "Prefix for .fit files filename prefix####suffix where #### are digits of file index",
+    "Prefix for .fit files filename prefix####suffix where #### are digits of file index. Check the value of 'nbdigits' for a correct automatic recognition of prefix from full file name",
     'peak list filename suffix. ".dat" or ".cor"',
     "maximum nb of digits for zero padding of filename index.(e.g. nb of # in prefix####.dat)\n0 for no zero padding.",
     "starting file index (integer) or full path (str) to a file with list of file indices",
@@ -210,7 +210,6 @@ class IndexRefineParameters(wx.Frame):
                 self.materialpages_list.pop(nb_tabs - (tabindex + 1))
 
             self.nb_of_materials = len(self.materialpages_list)
-    #             print dir(self.nb)
 
     def OnTabChange(self, evt):
         """ nothing particular implemented  """
@@ -392,7 +391,7 @@ class PageMaterialPanel(wx.Panel):
 
         if kk in (1, 11):
             try:
-                v = int(val)
+                _ = int(val)
             except ValueError:
                 wx.MessageBox("Error in Index_Refine.py hascorrectvalue().\nWrong type %s! Must be integer"
                     % self.list_txtparamIR[kk], "Error")
@@ -462,9 +461,7 @@ class MainFrame_indexrefine(wx.Frame):
         wx.Frame.__init__(self, parent, _id, title, size=(900, 650))
 
         self.initialparameters = _initialparameters
-
         self.parent = parent
-
         self.dict_param_list = {}
         self.nb_of_materials = 1
 
@@ -581,7 +578,7 @@ class MainFrame_indexrefine(wx.Frame):
 
         hmap = wx.BoxSizer(wx.HORIZONTAL)
         hmap.Add(txt_mapshape, 0)
-        hmap.Add(self.txtctrl_mapshape, 0) 
+        hmap.Add(self.txtctrl_mapshape, 0)
         hmap.Add(self.trackingmode, 0)
 
         vbox = wx.BoxSizer(wx.VERTICAL)
@@ -698,7 +695,7 @@ class MainFrame_indexrefine(wx.Frame):
         """
         try:
             val = int(self.list_txtctrl[5].GetValue())
-            testpos = math.sqrt(val)
+            _ = math.sqrt(val)
         except ValueError:
             wx.MessageBox("nb of digits in filename must be a positive integer! Please check the "
                                                                     "corresponding field!", "Info")
@@ -713,13 +710,6 @@ class MainFrame_indexrefine(wx.Frame):
 
             self.list_txtctrl[9].SetValue(folder.GetPath())
 
-    #     def OnbtnBrowse_fileReferenceCalibrationdat(self, event):
-    #         folder = wx.FileDialog(self, "Select Peaklist File .dat of Calibration Reference",
-    #                                wildcard='PeakList (*.dat)|*.dat|All files(*)|*')
-    #         if folder.ShowModal() == wx.ID_OK:
-    #
-    #             self.list_txtctrl[10].SetValue(folder.GetPath())
-
     def OnbtnBrowse_matsfile(self, _):
         """ get .mats file fullpath and set corresponding txtctrl"""
         print("OnbtnBrowse_matsfile")
@@ -800,16 +790,14 @@ class MainFrame_indexrefine(wx.Frame):
                 self.referencefiledat_purged = filter_peaks(referencefiledat_init,
                                                         maxpixdev=MAXPIXDEV_CALIBRATIONREFINEMENT)
                 #(calib_fitfilename, npeaks_LT, pixdev_LT,
-                (calib_fitfilename, _, _,
-                ) = index_refine_calib_one_image(self.referencefiledat_purged, filedet=filedet)
+                calib_fitfilename = index_refine_calib_one_image(self.referencefiledat_purged, filedet=filedet)[0]
             else:
                 raise ValueError("filter_peaks_index_refine_calib=1 without .dat file of peaks "
                 "used for calibration is no more used in Index_refine()")
 
         else:
             # (calib_fitfilename, npeaks_LT, pixdev_LT) = index_refine_calib_one_image
-            (calib_fitfilename, _, _) = index_refine_calib_one_image(
-                self.referencefiledat_purged, filedet=filedet)
+            calib_fitfilename = index_refine_calib_one_image(self.referencefiledat_purged, filedet=filedet)[0]
 
         self.initialparameters["CCDcalibrationReference .fit file"] = calib_fitfilename
         print("CCDcalibrationReference .fit file : %s" % calib_fitfilename)
@@ -910,7 +898,7 @@ class MainFrame_indexrefine(wx.Frame):
 
         #-------  field 5 : Nbdigits in index filename --------------
         nbdigits_filename = self.getnbdigits()
-            
+
         #-------  field 1, 2 & 3: PeakList .dat Folder, .cor folder & .fit folder  ----------
         filepathdat = self.list_txtctrl[0].GetValue()
         filepathcor = self.list_txtctrl[1].GetValue()
@@ -1010,7 +998,7 @@ class MainFrame_indexrefine(wx.Frame):
 
         verbosemode = self.verbosemode.GetValue()
 
-        # ------  field 11: Minimum matching rate 
+        # ------  field 11: Minimum matching rate
         MinimumMatchingRate = float(self.list_txtctrl[11].GetValue())
         print("MinimumMatchingRate to avoid starting general indexation is ", MinimumMatchingRate)
 
@@ -1019,7 +1007,7 @@ class MainFrame_indexrefine(wx.Frame):
         # before doing (maybe long) indexation from scratch
         guessedMatricesFile = str(self.list_txtctrl[10].GetValue())
         print("guessedMatricesFile", guessedMatricesFile)
-        
+
         if guessedMatricesFile not in ("None", "none", 'NONE'):
             print("Reading general file for guessed UB solutions")
 
@@ -1042,7 +1030,7 @@ class MainFrame_indexrefine(wx.Frame):
             Index_Refine_Parameters_dict["MinimumMatchingRate"] = MinimumMatchingRate
         else:
             # we are sure to be less than that!
-            Index_Refine_Parameters_dict["MinimumMatchingRate"] = max(0.123456,MinimumMatchingRate)
+            Index_Refine_Parameters_dict["MinimumMatchingRate"] = max(0.123456, MinimumMatchingRate)
 
         # ----------------------------------------------------------------------
 
@@ -1051,7 +1039,7 @@ class MainFrame_indexrefine(wx.Frame):
         # if spots positions evolve  for successive images
         trackingmode = self.trackingmode.GetValue()
         Index_Refine_Parameters_dict['trackingmode'] = trackingmode
-        
+
         rsl = self.list_txtctrl[13].GetValue()
         if rsl in ('None', "None", 'none', "none"):
             Index_Refine_Parameters_dict['Reference Spots List'] = None
@@ -1174,7 +1162,7 @@ initialparameters["MinimumMatchingRate"] = 4.0
 initialparameters["Selected Peaks from File"] = None
 
 # for local test:
-if 1:
+if 0:
     MainFolder = os.path.join(LaueToolsProjectFolder, "Examples", "CuSi")
     print("MainFolder", MainFolder)
     initialparameters["PeakList Folder"] = os.path.join(MainFolder, "corfiles")
@@ -1191,6 +1179,23 @@ if 1:
     initialparameters["startingindex"] = 0
     initialparameters["finalindex"] = 5
     initialparameters["stepindex"] = 1
+# for local test    guessUBmatrices on 3 grains
+if 1:
+    MainFolder = '/home/micha/LaueProjects/LauraConvert_TiLaser_Nov2020/LaserTi/T40'
+    print("MainFolder", MainFolder)
+    initialparameters["PeakList Folder"] = os.path.join(MainFolder, "datfiles")
+    initialparameters["IndexRefine PeakList Folder"] = os.path.join(MainFolder, "fitfiles")
+    initialparameters["PeakListCor Folder"] = os.path.join(MainFolder, "corfiles")
+    initialparameters["PeakList Filename Prefix"] = "T40N20_"
+    initialparameters["IndexRefine Parameters File"] = "/home/micha/LaueProjects/LauraConvert_TiLaser_Nov2020/LaserTi/T40/datfiles/T40N20.irp"
+    initialparameters["PeakList Filename Suffix"] = ".dat"
+    initialparameters["Detector Calibration File .det"] = '/home/micha/LaueProjects/LauraConvert_TiLaser_Nov2020/LaserTi/calibLaura20Nov20.det'
+    initialparameters["nbdigits"] = 4
+    initialparameters["Selected Peaks from File"] = 'None'
+
+    initialparameters["startingindex"] = 8
+    initialparameters["finalindex"] = 10
+    initialparameters["stepindex"] = 1
 
 # for local test:
 if 0:
@@ -1228,18 +1233,4 @@ def start():
     IndexRefineSeriesApp.MainLoop()
 
 if __name__ == "__main__":
-
-    #     if 0:
-    #         MainFolder = '/media/data3D/data/2013/July13/MA1724/'
-    #
-    #         initialparameters['PeakList Folder'] = MainFolder + 'Snsurfscan/datfiles'
-    #         initialparameters['IndexRefine PeakList Folder'] = MainFolder + 'Snsurfscan/fitfiles'
-    #         initialparameters['PeakListCor Folder'] = MainFolder + 'Snsurfscan/corfiles'
-    #         initialparameters['PeakList Filename Prefix'] = 'SnsurfscanBig_'
-    #         initialparameters['IndexRefine Parameters File'] = MainFolder + 'Snsurfscan/indexSn.irp'
-    #         initialparameters['Detector Calibration File .det'] = MainFolder + 'Gemono/GeMAR_HallJul13.det'
-    #         initialparameters['Detector Calibration File (.dat)'] = MainFolder + 'Gemono/Ge_0005_LT_1.dat'
-
-    # -----------------------------------------------------------
-
     start()
