@@ -25,11 +25,11 @@ np.set_printoptions(precision=15)
 if sys.version_info.major == 3:
     from . dict_LaueTools import CST_ENERGYKEV, CCD_CALIBRATION_PARAMETERS
     PYTHON3 = True
-    print('you are using python 3')
+    print('-- OK! You are using python 3')
 else:
     from dict_LaueTools import CST_ENERGYKEV, CCD_CALIBRATION_PARAMETERS
     PYTHON3 = False
-    print('you are using python 2. Better install python 3')
+    print('-- OK! you are using python 2 but tetter install python 3')
 
 DEFAULT_CCDLABEL = 'sCMOS'
 
@@ -39,16 +39,17 @@ def convert2corfile():
     pass
 
 
-def writefile_cor(prefixfilename, twicetheta, chi, data_x, data_y, dataintensity, param=None,
-                                                                            initialfilename=None,
-                                                                            comments=None,
-                                                                            sortedexit=0,
-                                                                            overwrite=1,
-                                                                            data_sat=None,
-                                                                            data_props=None,
-                                                                            rectpix=0,  # RECTPIX
-                                                                            dirname_output=None,
-                                                                            verbose=0):
+def writefile_cor(prefixfilename, twicetheta, chi, data_x, data_y, dataintensity,
+                                            param=None,
+                                            initialfilename=None,
+                                            comments=None,
+                                            sortedexit=0,
+                                            overwrite=1,
+                                            data_sat=None,
+                                            data_props=None,
+                                            rectpix=0,  # RECTPIX
+                                            dirname_output=None,
+                                            verbose=0):
     """
     Write .cor file containing data
     one line   of header
@@ -208,11 +209,7 @@ def readfile_cor(filename, output_CCDparamsdict=False):
     read peak list in .cor file which is contain 2theta and chi angles for each peak
     .cor file is made of 5 columns
 
-    2theta chi pixX pixY I
-
-    NOTE: detector parameters has been used previously to compute 2theta and chi (angles of kf)
-    from pixX and pixY, ie 2theta chi are detector position independent
-    (see find2thetachi for definition of kf)
+    2theta chi pixX pixY 
 
     :return: alldata                  #array with all spots properties)
             data_theta, data_chi,
@@ -220,6 +217,10 @@ def readfile_cor(filename, output_CCDparamsdict=False):
             data_I,                            # intensity
             detector parameters
 
+    NOTE: detector parameters has been used previously to compute 2theta and chi (angles of kf)
+    from pixX and pixY, ie 2theta chi are detector position independent
+    (see find2thetachi for definition of kf)
+
     #TODO: output 2theta ?
     """
     SKIPROWS = 1
@@ -500,10 +501,14 @@ def readStringOfIterable(striter):
 def writefile_Peaklist(outputprefixfilename, Data_array, overwrite=1,
                                                         initialfilename=None,
                                                         comments=None,
-                                                        dirname=None):
+                                                        dirname=None,
+                                                        verbose=0):
     """
     Write .dat file
 
+    :param dirname: output file dirname
+
+
     containing data
     one line   of header
     next lines of data
@@ -614,8 +619,9 @@ def writefile_Peaklist(outputprefixfilename, Data_array, overwrite=1,
 
     outputfile.close()
 
-    print("table of %d peak(s) with %d columns has been written in \n%s"
-        % (nbpeaks, nbcolumns, os.path.join(os.path.abspath(dirname), outputfilename)))
+    if verbose:
+        print("table of %d peak(s) with %d columns has been written in \n%s"
+            % (nbpeaks, nbcolumns, os.path.join(os.path.abspath(dirname), outputfilename)))
 
     return os.path.join(os.path.abspath(dirname), outputfilename)
 
@@ -675,12 +681,12 @@ def addPeaks_in_Peaklist(
     return merged_data
 
 
-def readfile_dat(filename_in, dirname=None):
+def readfile_dat(filename_in, dirname=None, returnnbpeaks = False):
     """ call simply read_Peaklist()"""
-    return read_Peaklist(filename_in, dirname=dirname)
+    return read_Peaklist(filename_in, dirname=dirname, returnnbpeaks=returnnbpeaks)
 
 
-def read_Peaklist(filename_in, dirname=None, output_columnsname=False):
+def read_Peaklist(filename_in, dirname=None, output_columnsname=False, returnnbpeaks = False):
     """
     read peak list .dat file and return the entire array of spots data
 
@@ -692,7 +698,22 @@ def read_Peaklist(filename_in, dirname=None, output_columnsname=False):
 
     SKIPROWS = 1
 
-    data_peak = np.loadtxt(filename_in, skiprows=SKIPROWS)
+    with open(filename_in) as f:
+        lineindex=0
+        commentfound = False
+        while not commentfound:
+            _line = f.readline()
+            if _line.startswith('# File created'):
+                nbdatarows = lineindex-1
+            elif _line.startswith('# Comments: nb of peaks'):
+                nbpeaks = int(_line.split('peaks')[-1])
+            elif _line.startswith('# Remove_BlackListedPeaks_fromfile'):
+                commentfound = True
+            lineindex+=1
+
+
+        # File created at
+    data_peak = np.loadtxt(filename_in, skiprows=SKIPROWS, max_rows=nbdatarows)
 
     if output_columnsname:
         f = open(filename_in, 'r')
@@ -700,6 +721,9 @@ def read_Peaklist(filename_in, dirname=None, output_columnsname=False):
         f.close()
         return data_peak, output_columnsname
 
+    if returnnbpeaks:
+        return data_peak, nbdatarows
+
     return data_peak
 
 
@@ -914,7 +938,8 @@ def readfitfile_multigrains(fitfilename, verbose=0, readmore=False,
                         euler                    : list of 3 Euler Angles for each grain
 
     """
-    print("reading fit file %s by readfitfile_multigrains.py of IOLaueTools (formerly readwriteASCII): " % fitfilename)
+    if verbose:
+        print("reading fit file %s by readfitfile_multigrains.py of IOLaueTools (formerly readwriteASCII): " % fitfilename)
 
     columns_headers = []
 
@@ -924,19 +949,21 @@ def readfitfile_multigrains(fitfilename, verbose=0, readmore=False,
     nbgrains = 0
     linepos_grain_list = []
     lineindex = 1
+    WrongExtension = False
     try:
         for line in f:
-            #             _line = line.rstrip(("\n", '\r', '\t'))
             _line = line.rstrip(string.whitespace)
-
-            if _line.endswith(fileextensionmarker) and not _line.startswith(
-                "# Unindexed and unrefined"):
-                nbgrains += 1
-                linepos_grain_list.append(lineindex)
+            if not _line.startswith("# Unindexed and unrefined"):
+                if _line.endswith(fileextensionmarker):
+                    nbgrains += 1
+                    linepos_grain_list.append(lineindex)
+                else:
+                    WrongExtension = True
             lineindex += 1
+        if WrongExtension:
+            print('Warning !! Strange extension file for the first line of %s'%fitfilename)
     finally:
         linepos_grain_list.append(lineindex)
-        #         print "found grains and close file"
         f.close()
 
     if verbose:
@@ -945,7 +972,7 @@ def readfitfile_multigrains(fitfilename, verbose=0, readmore=False,
 
     # nothing has been indexed
     if nbgrains == 0:
-        return 0
+        return None
 
     list_indexedgrains_indices = list(range(nbgrains))
 
@@ -969,12 +996,6 @@ def readfitfile_multigrains(fitfilename, verbose=0, readmore=False,
     UBmat = np.zeros((3, 3), dtype=np.float)
     strain = np.zeros((3, 3), dtype=np.float)
 
-    #     n = linepos_grain_list[grain_index]
-    #         # print "n = ", n
-    #         # Now, to skip to line n (with the first line being line 0), just do
-    #         f.seek(line_offset[n])
-    #         # print f.readline()
-    #         f.seek(line_offset[n + 1])
     matrixfound = 0
     calibfound = 0
     calibfoundJSM = 0
@@ -985,16 +1006,11 @@ def readfitfile_multigrains(fitfilename, verbose=0, readmore=False,
     linepixdev = 0
     #linestrain = 0
     lineeuler = 0
-    #list1 = []
-    #linestartspot = 10000
-    #lineendspot = 10000
 
     f = open(fitfilename, "r")
     unindexedspots = False
     for grain_index in list(range(nbgrains)):
-        #         print "read data for grain_index %d" % grain_index
-        #         print linepos_grain_list[grain_index + 1]
-        #         print linepos_grain_list[grain_index]
+
         iline = linepos_grain_list[grain_index]
 
         nb_indexed_spots = 0
@@ -1043,7 +1059,6 @@ def readfitfile_multigrains(fitfilename, verbose=0, readmore=False,
                             line.rstrip("\n").replace("#", "").replace("[", "").replace("]", "").split())
 
                     dataspots = np.array(dataspots, dtype=np.float)
-                #                     print "got dataspots!"
 
                 elif nb_UNindexed_spots > 0:
                     nbspots = nb_UNindexed_spots
@@ -1079,7 +1094,7 @@ def readfitfile_multigrains(fitfilename, verbose=0, readmore=False,
                 eulerfound = 1
                 lineeuler = iline + 1
 
-                print('matrixfound', matrixfound)
+                print('Eulers Angles found', eulerfound)
 
             if matrixfound:
                 for jline_matrix in list(range(3)):
@@ -1211,7 +1226,7 @@ def readfitfile_multigrains(fitfilename, verbose=0, readmore=False,
         return _res
 
 def readfitfile_comments(fitfilepath):
-    """read comments and return corresponding strings
+    """read comments in .fit file and return corresponding strings
     #CCDLabel
     #pixelsize
     #Frame dimensions
@@ -1825,6 +1840,8 @@ def ReadSpec(fname, scan, outputdate=False):
     """
     f = open(fname, "r")
 
+    print('ReadSpec of IOLaueTools.py')
+
     s = "#S %d" % scan
     title = 0
 
@@ -1868,8 +1885,12 @@ def ReadSpec(fname, scan, outputdate=False):
         if len(l) < 2:
             break
 
-        if l[:2] == "#C":
-            if not l.startswith("#C tiltcomp:"):
+        if l[:2] == "#C":            
+            # deal with#C Thu Feb 25 23:54:05 2021.  Erreur com with laueT.
+            if 'Erreur com' in l:
+                print('line error #C :', l)
+                continue
+            elif not l.startswith("#C tiltcomp:"):
                 print("Scan aborted after %d point(s)" % ii)
                 break
             else:
