@@ -16,7 +16,10 @@ import struct
 
 # third party modules
 try:
-    import fabio
+    import warnings
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore",category=FutureWarning)
+        import fabio
 
     FABIO_EXISTS = True
 except ImportError:
@@ -109,7 +112,7 @@ def setfilename(imagefilename, imageindex, nbdigits=4, CCDLabel=None, verbose=0)
                 #imagefilename = imagefilename[: - (lenext + nbdigits)].zfill(nbdigits) + "%s" % ext
 
                 prepart = str(imagefilename).rsplit('.',1)[0]
-                prefix, digitpart = str(prepart).split('_', 1)
+                prefix, digitpart = str(prepart).rsplit('_', 1)
                 imagefilename = prefix + "_" + str(imageindex).zfill(nbdigits) + "." + ext
             elif imagefilename.endswith(ext+".gz"):
                 imagefilename = imagefilename[: -(lenext+3 + nbdigits)] + "{:04d}.{}.gz".format(imageindex, ext)
@@ -117,7 +120,7 @@ def setfilename(imagefilename, imageindex, nbdigits=4, CCDLabel=None, verbose=0)
         else:
             if imagefilename.endswith(ext):
                 prefix, _ = imagefilename.split(".")
-                prefix0 = prefix.split("_")[0]
+                prefix0 = prefix.rsplit("_")[0]
                 if imageindex > 9999:
                     imagefilename = prefix0 + "_{}.{}".format(imageindex, ext)
                 else:
@@ -141,7 +144,7 @@ def setfilename(imagefilename, imageindex, nbdigits=4, CCDLabel=None, verbose=0)
             sname2 = sname[-2] + "_" + sname[-1]
             prefix = imagefilename.rstrip(sname2)
         else:
-            prefix = imagefilename.split("_")[0]
+            prefix = imagefilename.rsplit("_")[0]
         imagefilename = prefix + "_{}_mar.tif".format(imageindex)
 
     # special case for image id15 frelon corrected form distorsion
@@ -203,7 +206,7 @@ def getIndex_fromfilename(imagefilename, nbdigits=4, CCDLabel=None, stackimagein
             if imagefilename.endswith(ext):
                 #imageindex = int(imagefilename[-(lenext + nbdigits): - (lenext)])
                 prepart = str(imagefilename).rsplit('.',1)[0]
-                digitpart = str(prepart).split('_',1)[-1]
+                digitpart = str(prepart).rsplit('_',1)[-1]
                 print("prepart", prepart)
                 print("digitpart",digitpart)
                 imageindex = int(digitpart)
@@ -211,8 +214,8 @@ def getIndex_fromfilename(imagefilename, nbdigits=4, CCDLabel=None, stackimagein
                 imageindex = int(imagefilename[-(lenext+3 + nbdigits) : -(lenext+3)])
         else:
             if imagefilename.endswith(ext):
-                prefix, _ = imagefilename.split(".")
-                imageindex = int(prefix.split("_")[1])
+                prefix, _ = imagefilename.rsplit(".")
+                imageindex = int(prefix.rsplit("_")[1])
 
     # for stacked images we return the position of image data in the stack as imagefileindex
     elif CCDLabel in ("EIGER_4Mstack",):
@@ -600,16 +603,16 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
             dataimage = np.array(im.getdata()).reshape(framedim)
 
     # RAW method knowing or deducing offsetheader and dataformat
-    if USE_RAW_METHOD:
-        if verbose > 1: print("----> not using libtiff, nor fabio, nor PIL!!!  ")
+    else:#USE_RAW_METHOD:
+        print("----> !!! not using libtiff, nor fabio, nor PIL!!!  ")
         if CCDLabel in ("MARCCD165",):
             print("for MARCCD not using libtiff, raw method ...")
             # offsetheader may change ...
-            #filesize = os.path.getsize(os.path.join(dirname, filename))
+            #filesize=getfilesize(dirname, filename)
             offsetheader = 4096 #filesize - 2048*2048 * 2
         # offset header varying
         elif CCDLabel.startswith("ImageStar_raw"):
-            filesize = os.path.getsize(os.path.join(dirname, filename))
+            filesize=getfilesize(dirname, filename)
             bytes_per_pixels = 2
             if CCDLabel.endswith("32bits"):
                 bytes_per_pixels = 4
@@ -621,7 +624,7 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
         elif CCDLabel in ("sCMOS",):
             if verbose > 0: print("for sCMOS not using libtiff, raw method ...")
             # offsetheader may change ...
-            filesize = os.path.getsize(os.path.join(dirname, filename))
+            filesize=getfilesize(dirname, filename)
             offsetheader = filesize - 2016*2018 * 2
 
         dataimage = readoneimage(filename,
@@ -642,14 +645,14 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
                 print("formatdata", formatdata)
                 print("dataimage", dataimage)
 
-    if verbose > 0:
+    if verbose:
         print("CCDLabel: ", CCDLabel)
         print("nb of pixels", np.shape(dataimage))
 
     # need to reshape data from 1D to 2D
     try:
         if len(dataimage.shape) == 1:
-            if verbose > 0:
+            if verbose:
                 print("nb elements", len(dataimage))
                 print("framedim", framedim)
                 print("framedim nb of elements", framedim[0] * framedim[1])
@@ -683,6 +686,12 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
 
     return dataimage, framedim, fliprot
 
+def getfilesize(dirname,filename):
+    if dirname is not None:
+        filesize = os.path.getsize(os.path.join(dirname, filename))
+    else:
+        filesize = os.path.getsize(filename)
+    return filesize
 
 def readoneimage(filename, framedim=(2048, 2048), dirname=None, offset=4096, formatdata="uint16"):
     r""" returns a 1d array of integers from a binary image file (full data)
@@ -814,7 +823,7 @@ def readoneimage_crop_fast(filename, dirname=None, CCDLabel="MARCCD165",
 
 def readrectangle_in_image(filename, pixx, pixy, halfboxx, halfboxy, dirname=None,
                                                                             CCDLabel="MARCCD165",
-                                                                            verbose=True):
+                                                                            verbose=0):
     r"""
     returns a 2d array of integers from a binary image file. Data are taken only from a rectangle
     centered on pixx, pixy
