@@ -15,13 +15,9 @@ import re
 
 import numpy as np
 
-# LAUETOOLSFOLDER = os.getcwd()
-
 LAUETOOLSFOLDER = os.path.split(__file__)[0]
-
-print("LaueToolsProjectFolder", LAUETOOLSFOLDER)
-
-WRITEFOLDER = os.path.join(LAUETOOLSFOLDER, "laueanalysis")
+# print("LaueToolsProjectFolder", LAUETOOLSFOLDER)
+# WRITEFOLDER = os.path.join(LAUETOOLSFOLDER, "laueanalysis")
 
 ##------------------------------------------------------------------------
 # --- -----------  Element-materials library
@@ -88,6 +84,8 @@ dict_Materials = {
     "GaN_all": ["GaN_all", [3.189, 3.189, 5.185, 90, 90, 120], "no"],
     "In": ["In", [3.2517, 3.2517, 4.9459, 90, 90, 90], "h+k+l=2n"],
     "InN": ["InN", [3.533, 3.533, 5.693, 90, 90, 120], "wurtzite"],
+    "In2Bi": ["In2Bi", [5.496, 5.496, 6.585, 90, 90, 120], "no"],  # GS 194
+    "In_epsilon": ["In_epsilon", [3.47, 3.47, 4.49, 90, 90, 90], "no"], #"h+k+l=2n"],  # GS 
     "InGaN": ["InGaN", [(3.533 + 3.189) / 2.0, (3.533 + 3.189) / 2.0, (5.693 + 5.185) / 2.0, 90, 90, 120, ], "wurtzite", ],  # wegard's law
     "Ti_s": ["Ti_s", [3.0, 3.0, 4.7, 90.5, 89.5, 120.5], "no"],  # Ti strained
     "inputB": ["inputB", [1.0, 1.0, 1.0, 90, 90, 90], "no"],
@@ -101,13 +99,16 @@ dict_Materials = {
     "Sb": ["Sb", [4.3, 4.3, 11.3, 90, 90, 120], "no"],
     "quartz_alpha": ["quartz_alpha", [4.913, 4.913, 5.404, 90, 90, 120], "no"],
     "ferrydrite": ["ferrydrite", [2.96, 2.96, 9.4, 90, 90, 120], "no"],
+    "feldspath": ["feldspath", [8.59, 12.985,7.213, 90, 116., 90], 'no'], 
     "hexagonal": ["hexagonal", [1.0, 1.0, 3.0, 90, 90, 120.0], "no"],
     "ZnO": ["ZnO", [3.252, 3.252, 5.213, 90, 90, 120], "wurtzite"],
     "test_reference": ["test_reference", [3.2, 4.5, 5.2, 83, 92.0, 122], "wurtzite"],
-    "test_solution": ["test_solution", [3.252, 4.48, 5.213, 83.2569, 92.125478, 122.364], "wurtzite", ],
+    "test_solution": ["test_solution", [3.252, 4.48, 5.213, 83.2569, 92.125478, 122.364], "wurtzite",],
+    "Y2SiO5": ["Y2SiO5", [10.34, 6.689, 12.38, 90.0, 102.5, 90.0], "no", ],  # SG 15  I2/a
     "VO2M1": ["VO2M1", [5.75175, 4.52596, 5.38326, 90.0, 122.6148, 90.0], "VO2_mono", ],  # SG 14
-    "VO2M2": ["VO2M2", [4.5546, 4.5546, 2.8514, 90.0, 90, 90.0], "no", ],  # SG 136 (87 deg Celsius)  Rutile
-    "VO2R": ["VO2R", [4.5546, 4.5546, 2.8514, 90.0, 90, 90.0], "rutile", ],  # SG 136 (87 deg Celsius)  Rutile
+    "VO2M2": ["VO2M2", [4.5546, 4.5546, 2.8514, 90.0, 90, 90.0], "no" ],  # SG 136 (87 deg Celsius)  Rutile
+    "VO2R": ["VO2R", [4.5546, 4.5546, 2.8514, 90.0, 90, 90.0], "rutile"],  # SG 136 (87 deg Celsius)  Rutile
+    "ZnCuOCl": ["ZnCuOCl", [6.839, 6.839 , 14.08, 90.0, 90, 120.0], "no"],
 }
 
 dict_Materials_short = {
@@ -341,7 +342,10 @@ def getwildcardstring(CCDlabel):
 
     extensions = copy.copy(ALL_EXTENSIONS)
     infos = copy.copy(INFO_EXTENSIONS)
-    chosen_extension = dict_CCD[CCDlabel][7]
+    if CCDlabel != '*':
+        chosen_extension = dict_CCD[CCDlabel][7]
+    else:
+        chosen_extension = ''
 
     if chosen_extension in ALL_EXTENSIONS:
         index = ALL_EXTENSIONS.index(chosen_extension)
@@ -776,6 +780,6 @@ SLIPSYSTEMS_FCC = np.array([[1, 1, 1], [0, -1, 1],
     [1, -1, 1], [0, 1, 1],
     [1, -1, 1], [-1, 0, 1],
     [1, -1, 1], [1, 1, 0],
-    [1, 1, -1], [0, -1, 1],
-    [1, 1, -1], [-1, 0, 1],
-    [1, 1, -1], [-1, 1, 0], ]).reshape((12, 2, 3))
+    [1, 1, -1], [0, 1, 1],
+    [1, 1, -1], [1, 0, 1],
+    [1, 1, -1], [-1, 1, 0]]).reshape((12, 2, 3))
