@@ -45,9 +45,9 @@ try:
 
     USE_CYTHON = True
 except ImportError:
-    print("Cython compiled 'angulardist' module for fast computation of "
-                                                            "angular distance is not installed!")
-    print("Using default module")
+    # print("-- warning. Cython compiled 'angulardist' module for fast computation of "
+    #                                                         "angular distance is not installed!")
+    # print("Using default module")
     USE_CYTHON = False
 
 
@@ -659,7 +659,7 @@ def Angular_residues_np(test_Matrix, twicetheta_data, chi_data, ang_tol=0.5,
     :param ang_tol: angular tolerance in degrees to accept or reject a exp. and theo pair
     :type ang_tol: scalar
 
-    :param detectorparameters: Dictionary of detector parameters (key, value) that must constain:
+    :param detectorparameters: Dictionary of detector parameters (key, value) that must contain:
                             'kf_direction' , general position of detector plane
                             'detectordistance', detector distance (mm)
                             'detectordiameter', detector diameter (mm)
